#include "PokktExtension.h"
#include "PokktNativeManager.h"
#include <string>

void PokktExtension::PokktCallbackReceived(CallbackData* data, void* userData)
{
    PokktNativeManager::handleNativeMessage(data->operation, data->params);
}

void PokktExtension::notifyNative(std::string operation, std::string param)
{
    notifyExtensionOnNative(operation.c_str(), param.c_str());
}

bool PokktExtension::isVideoAvailable()
{
    return isVideoAvailableOnNative();
}

double PokktExtension::getVideoVc()
{
    return getVideoVcOnNative();
}

std::string PokktExtension::getPokktSDKVersion()
{
    std::string ret(getPokktSDKVersionOnNative());
    return ret;
}

void PokktExtension::performOperation(PokktOperations operation, std::string param)
{
    switch (operation)
    {
            // common methods
        case SetParams:                 notifyNative("setParams",               param);   break;
        case SetDebug:                  notifyNative("setDebug",                param);   break;
        case ShowLog:                   notifyNative("showLog",                 param);   break;
        case ShowToast:                 notifyNative("showToast",               param);   break;
        case SetThirdPartyUserId:       notifyNative("setThirdPartyUserId",     param);   break;
            
            // session methods
        case StartSession:              notifyNative("startSession",            param);   break;
        case EndSession:                notifyNative("endSession",              param);   break;
            
            // offerWall Methods
        case SetCloseOnSuccessFlag:     notifyNative("setCloseOnSuccessFlag",   param);   break;
        case GetCoins:                  notifyNative("getCoins",                param);   break;
        case GetPendingCoins:           notifyNative("getPendingCoins",     	param);   break;
        case CheckOfferWallCampaign:    notifyNative("checkOfferWallCampaign",  param);   break;
            
            // video methods
        case GetVideo:                  notifyNative("getVideo",            	param);   break;
        case GetVideoNonIncent:    		notifyNative("getVideoNonIncent",   	param);   break;
        case CacheVideoCampaign:        notifyNative("cacheVideoCampaign",      param);   break;
        case SetSkipEnabled:          	notifyNative("setSkipEnabled",        	param);   break;
        case SetDefaultSkipTime:    	notifyNative("setDefaultSkipTime",      param);   break;
        case SetCustomSkipMessage:    	notifyNative("setCustomSkipMessage",    param);   break;
        case SetBackButtonDisabled:    	notifyNative("setBackButtonDisabled",   param);   break;
            
            // optional methods
        case SetName:                   notifyNative("setName",                 param);   break;
        case SetAge:                    notifyNative("setAge",              	param);   break;
        case SetSex:                    notifyNative("setSex",              	param);   break;
        case SetMobileNo:               notifyNative("setMobileNo",             param);   break;
        case SetEmailAddress:           notifyNative("setEmailAddress",         param);   break;
        case SetLocation:               notifyNative("setLocation",             param);   break;
        case SetBirthday:               notifyNative("setBirthday",             param);   break;
        case SetMaritalStatus:          notifyNative("setMaritalStatus",        param);   break;
        case SetFacebookId:             notifyNative("setFacebookId",           param);   break;
        case SetTwitterHandle:          notifyNative("setTwitterHandle",        param);   break;
        case SetEducation:              notifyNative("setEducation",            param);   break;
        case SetNationality:            notifyNative("setNationality",          param);   break;
        case SetEmployment:             notifyNative("setEmployment",           param);   break;
        case SetMaturityRating:         notifyNative("setMaturityRating",       param);   break;
    }
}
