/*
 * android-specific implementation of the PokktNativeExtension extension.
 * Add any platform-specific functionality here.
 */
/*
 * NOTE: This file was originally written by the extension builder, but will not
 * be overwritten (unless --force is specified) and is intended to be modified.
 */
#include "PokktNativeExtension_internal.h"

#include "s3eEdk.h"
#include "s3eEdk_android.h"
#include <jni.h>
#include "IwDebug.h"
#include <string>

static jobject g_Obj;
static jmethodID g_notifyExtensionOnNative;
static jmethodID g_isVideoAvailableOnNative;
static jmethodID g_getVideoVcOnNative;
static jmethodID g_getPokktSDKVersionOnNative;

void JNICALL NotifyCPP(JNIEnv* env, jclass cls, jstring operation, jstring param)
{
    CallbackData data;
    data.operation = env->GetStringUTFChars(operation, 0);
    data.params = env->GetStringUTFChars(param, 0);
    
    IwTrace(POKKTNATIVEEXTENSION, ("NotifyCPP called success. operationString : %s", data.operation));
    IwTrace(POKKTNATIVEEXTENSION, ("NotifyCPP called success. paramString : %s", data.params));
    
    s3eEdkCallbacksEnqueue(S3E_EXT_POKKTNATIVEEXTENSION_HASH, OPERATION_EVENT, &data, sizeof(data));
    
    env->DeleteLocalRef(operation);
    env->DeleteLocalRef(param);
}

s3eResult PokktNativeExtensionInit_platform()
{
    // Get the environment from the pointer
    JNIEnv* env = s3eEdkJNIGetEnv();
    jobject obj = NULL;
    jmethodID cons = NULL;

    // Get the extension class
    jclass cls = s3eEdkAndroidFindClass("PokktNativeExtension");
    if (!cls)
        goto fail;

    // Get its constructor
    cons = env->GetMethodID(cls, "<init>", "()V");
    if (!cons)
        goto fail;

    // Construct the java class
    obj = env->NewObject(cls, cons);
    if (!obj)
        goto fail;

    // Get all the extension methods
    g_notifyExtensionOnNative = env->GetMethodID(cls, "notifyExtensionOnNative", "(Ljava/lang/String;Ljava/lang/String;)V");
    if (!g_notifyExtensionOnNative)
        goto fail;

    g_isVideoAvailableOnNative = env->GetMethodID(cls, "isVideoAvailableOnNative", "()Z");
    if (!g_isVideoAvailableOnNative)
        goto fail;

    g_getVideoVcOnNative = env->GetMethodID(cls, "getVideoVcOnNative", "()D");
    if (!g_getVideoVcOnNative)
        goto fail;
    
    g_getPokktSDKVersionOnNative = env->GetMethodID(cls,"getPokktSDKVersionOnNative","()Ljava/lang/String;");
    if (!g_getPokktSDKVersionOnNative)
        goto fail;

    IwTrace(POKKTNATIVEEXTENSION, ("POKKTNATIVEEXTENSION init success"));
    
    static const JNINativeMethod nativeMethods[] =
    {
        { "NotifyCPP", "(Ljava/lang/String;Ljava/lang/String;)V", (void *)&NotifyCPP }
    };
    
    // Register the native hooks
    if (env->RegisterNatives(cls, nativeMethods, sizeof(nativeMethods)/sizeof(nativeMethods[0])))
        goto fail;
    
    IwTrace(POKKTNATIVEEXTENSION, ("POKKTNATIVEEXTENSION Register Native Success"));
    
    g_Obj = env->NewGlobalRef(obj);
    env->DeleteLocalRef(obj);
    env->DeleteGlobalRef(cls);

    // Add any platform-specific initialisation code here
    return S3E_RESULT_SUCCESS;

fail:
    jthrowable exc = env->ExceptionOccurred();
    if (exc)
    {
        env->ExceptionDescribe();
        env->ExceptionClear();
        IwTrace(PokktNativeExtension, ("One or more java methods could not be found"));
    }

    env->DeleteLocalRef(obj);
    env->DeleteGlobalRef(cls);
    return S3E_RESULT_ERROR;
}

void PokktNativeExtensionTerminate_platform()
{ 
    // Add any platform-specific termination code here
    JNIEnv* env = s3eEdkJNIGetEnv();
    env->DeleteGlobalRef(g_Obj);
    g_Obj = NULL;
}

void notifyExtensionOnNative_platform(const char* operation, const char* param)
{
    JNIEnv* env = s3eEdkJNIGetEnv();
    jstring operation_jstr = env->NewStringUTF(operation);
    jstring param_jstr = env->NewStringUTF(param);
    env->CallVoidMethod(g_Obj, g_notifyExtensionOnNative, operation_jstr, param_jstr);
}

bool isVideoAvailableOnNative_platform()
{
    JNIEnv* env = s3eEdkJNIGetEnv();
    return (bool)env->CallBooleanMethod(g_Obj, g_isVideoAvailableOnNative);
}

double getVideoVcOnNative_platform()
{
    JNIEnv* env = s3eEdkJNIGetEnv();
    return (double)env->CallDoubleMethod(g_Obj, g_getVideoVcOnNative);
}

const char * getPokktSDKVersionOnNative_platform()
{
    JNIEnv* env = s3eEdkJNIGetEnv();


    jstring objStr = (jstring)env->CallObjectMethod(g_Obj, g_getPokktSDKVersionOnNative);
    
    jboolean isCopy;
    
    const char* result = env->GetStringUTFChars(objStr, &isCopy);
    
    IwTrace(PokktNativeExtension, ("getPokktSDKVersionOnNative_platform received from java 1: %s",result));
    
    std::string ret(result);
    
    IwTrace(PokktNativeExtension, ("getPokktSDKVersionOnNative_platform received from java 2: %s",ret.c_str()));
    
    if (isCopy)
    {
        env->ReleaseStringUTFChars(objStr, result);
    }
    
    IwTrace(PokktNativeExtension, ("getPokktSDKVersionOnNative_platform received from java 3: %s",ret.c_str()));
    
    return ret.c_str();
}
